@@ -30,10 +30,10 @@ class hamiltonian():
     ----------
     H0_g : array_like, shape (N, N), optional
         Ground manifold field-independent matrix
-    muq_g : array_like, shape (3, N, N), optional
-        Ground manifold magnetic field-dependent component, in spherical basis.
     H0_e : array_like, shape (M, M), optional
         Excited manifold field-independent matrix
+    muq_g : array_like, shape (3, N, N), optional
+        Ground manifold magnetic field-dependent component, in spherical basis.
     muq_e : array_like, shape (3, M, M), optional
         Excited manifold magnetic field-dependent component, in spherical basis.
     d_q : array_like, shape (3, N, M), optional
@@ -427,8 +427,15 @@ class hamiltonian():
 
         Parameters
         ----------
-        Eq : array_like, shape (3,)
-            The electric field in spherical basis.
+        Eq : array_like or dictionary of array_like
+            The electric field(s) driving transitions between manifolds,
+            each expressed in the spherical basis.  Each electric field
+            driving a transition between manifolds needs to specified with the
+            correct key in the dictionary.  For example, for a two-manifold
+            Hamiltonian with manifold labels `g` and `e`, the dictionary should
+            contain a single entry with `g->e`.  If the electric field is
+            given as a single array_like, it is assumed to drive the `g->e`
+            transition.
         Bq : array_like, shape (3,)
             The magnetic field in spherical basis.
 
@@ -442,7 +449,10 @@ class hamiltonian():
 
         H = self.H_0 - np.tensordot(self.mu_q, np.conjugate(Bq), axes=(0, 0))
 
-        for key in self.d_q_bare.keys():
+        if isinstance(Eq, list) or isinstance(Eq, np.ndarray):
+            Eq = {'g->e':Eq} # Promote to a dictionary.
+
+        for key in Eq.keys():
             for ii, q in enumerate(np.arange(-1., 2., 1.)):
                 H -= (0.5*(-1.)**q*self.d_q_bare[key][ii]*Eq[key][2-ii] +
                       0.5*(-1.)**q*self.d_q_star[key][ii]*np.conjugate(Eq[key][2-ii]))
