@@ -492,7 +492,7 @@ class rateeq(governingeq):
         Sets the initial populations based on the equilibrium population at
         the initial position and velocity and time t=0.
         """
-        self.N0 = self.equilibrium_populations(self.r0, self.v0, t=0)
+        self.N0 = self.equilibrium_populations(self.r0, self.v0, t=0.)
 
 
     def evolve_populations(self, t_span, **kwargs):
@@ -535,7 +535,8 @@ class rateeq(governingeq):
     def evolve_motion(self, t_span, freeze_axis=[False, False, False],
                       random_recoil=False, random_force=False,
                       max_scatter_probability=0.1, progress_bar=False,
-                      record_force=False, **kwargs):
+                      record_force=False, rng=np.random.default_rng(),
+                      **kwargs):
         """
         Evolve the populations :math:`N` and the motion of the atom in time.
 
@@ -570,6 +571,9 @@ class rateeq(governingeq):
         record_force : boolean
             If true, record the instantaneous force and store in the solution.
             Default: False
+        rng : numpy.random.Generator()
+            A properly-seeded random number generator.  Default: calls
+            ``numpy.random.default.rng()``
         **kwargs :
             Additional keyword arguments get passed to solve_ivp_random, which
             is what actually does the integration.
@@ -643,7 +647,7 @@ class rateeq(governingeq):
                 P = Rl*dt
 
                 # Roll the dice N times, where $N=\sum(lasers)
-                dice = np.random.rand(len(P))
+                dice = rng.random(len(P))
 
                 # Give them kicks!
                 for ii in np.arange(len(Rl))[dice<P]:
@@ -652,7 +656,7 @@ class rateeq(governingeq):
                                 self.hamiltonian.mass
                     # Can branch to a differe, lower state, but let's ignore that
                     # for the moment.
-                    y[-6:-3] += self.recoil_velocity[key]*(random_vector(free_axes))
+                    y[-6:-3] += self.recoil_velocity[key]*(random_vector(rng, free_axes))
 
                 total_P += np.sum(P)
 
@@ -672,14 +676,14 @@ class rateeq(governingeq):
                 P = dt*self.decay_rates[key]*y[self.decay_N_indices[key]]
 
                 # Roll the dice N times, where $N=\sum(n_i)
-                dice = np.random.rand(len(P))
+                dice = rng.random(len(P))
 
                 # For any random number that is lower than P_i, add a
                 # recoil velocity.
                 for ii in range(np.sum(dice<P)):
                     num_of_scatters += 1
-                    y[-6:-3] += self.recoil_velocity[key]*(random_vector(free_axes)+
-                                                           random_vector(free_axes))
+                    y[-6:-3] += self.recoil_velocity[key]*(random_vector(rng, free_axes)+
+                                                           random_vector(rng, free_axes))
 
                 # Save the total probability of a scatter:
                 total_P += np.sum(P)
@@ -767,7 +771,7 @@ class rateeq(governingeq):
             raise NotImplementedError('Time dependence not yet implemented.')
         else:
             N_eq, Rev, Rijl = self.equilibrium_populations(
-                self.r0, self.v0, t=0, return_details=True, **kwargs
+                self.r0, self.v0, t=0., return_details=True, **kwargs
                 )
 
             F_eq, f_eq, f_mag = self.force(self.r0, 0., N_eq)
@@ -786,11 +790,11 @@ class rateeq(governingeq):
         ----------
         R : array_like, shape(3, ...)
             Position vector.  First dimension of the array must be length 3, and
-            corresponds to :math:`x`, :math:`y`, and :math`z` components,
+            corresponds to :math:`x`, :math:`y`, and :math:`z` components,
             repsectively.
         V : array_like, shape(3, ...)
             Velocity vector.  First dimension of the array must be length 3, and
-            corresponds to :math:`v_x`, :math:`v_y`, and :math`v_z` components,
+            corresponds to :math:`v_x`, :math:`v_y`, and :math:`v_z` components,
             repsectively.
         name : str, optional
             Name for the profile.  Stored in profile dictionary in this object.
